function fobj = fenv(fobjarr)
	% -- f = fenv({f1,...,fn})    lower closed convex envelope
	%
	%    lower closed convex envelope of n polyhedral functions
	%
	%    corresponds to convex hull of the union of epigraphs
	%
	%    Input:
	%      {f1,...,fn}: n polyhedral convex functions with same number
	%                   of variables (cell array of polyf objects)
	%    Output:
	%      f: lower closed convex envelope (polyf object)
	%
	%    see also: finfc, fmax, fsum
	%
	%    for further information, see http://bensolve.org/files/manual.pdf

	nn=length(fobjarr);
	for i=1:nn
		if ~isobject(fobjarr{i})
			error('invalid entry in cell array');
		end
	end
	if nn>=1
		nvar=fobjarr{1}.nvar;
	else
		error('invalid input');
	end
	for i=1:nn
		if fobjarr{i}.nvar ~= nvar
			error('functions do not have the same number of variables');
		end
	end
	carr=cell(nn,1);
	for i=1:nn
		carr{i}=fobjarr{i}.epi;
	end
	epi=chunion(carr); %#ok
	fobj=polyf(epi);
end
